@@ -1,7 +1,7 @@
 #
 # atimer - timer library for asyncio
-# 
-# Copyright (C) 2016-2021 by Artur Wroblewski <wrobell@riseup.net>
+#
+# Copyright (C) 2016 - 2024 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,11 +30,11 @@ The main features are
 - measure time while system is suspended
 """
 
-import pkg_resources
+from importlib.metadata import version
 
 from .glue import Timer
 
-__version__ = pkg_resources.get_distribution('atimer').version
+__version__ = version('atimer')
 
 __all__ = ['Timer']
 
