@@ -1,7 +1,7 @@
 #
 # atimer - timer library for asyncio
 #
-# Copyright (C) 2016-2021 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2016 - 2024 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,16 +25,26 @@ import asyncio
 import logging
 import os
 import struct
+import typing as tp
+from collections.abc import Awaitable
 
 from ._atimer import atimer_init, atimer_start, atimer_close  # type: ignore
 
 logger = logging.getLogger(__name__)
 
-class Timer(object):
+class Timer(Awaitable[int]):
     """
     Timer based on Linux `timerfd` interface.
+
+    Timer object is a Python asynchronous coroutine. It waits for timer
+    expiration. An awaited coroutine returns number of timer expirations.
+
+    The number of expirations is usually `1` until timer overrun happens.
+    Refer to POSIX documentation for definition of the timer overrun.
+
+    :param interval: Interval, in seconds, at which the timer expires.
     """
-    def __init__(self, interval):
+    def __init__(self, interval: float):
         """
         Create timer object.
 
@@ -42,34 +52,29 @@ class Timer(object):
         """
         self._fd = atimer_init()
         self._interval = interval
-        self._task = None
-        self._loop = None
+        self._task: asyncio.Future[int] | None = None
+        self._loop: asyncio.AbstractEventLoop | None = None
 
-    def start(self):
+    def start(self) -> None:
         """
         Arm the timer.
         """
-        self._loop = asyncio.get_event_loop()
+        self._loop = asyncio.get_running_loop()
         self._loop.add_reader(self._fd, self._timer_expired)
         atimer_start(self._fd, self._interval)
         if __debug__:
             logger.debug('timer armed')
 
-    def __await__(self):
-        """
-        Wait for timer expiration.
-
-        Return number of timer expirations. The number of expirations is
-        usually `1` until timer overrun happens. Refer to POSIX
-        documentation for definition of timer overrun.
-        """
+    def __await__(self) -> tp.Generator[tp.Any, None, int]:
+        assert self._loop is not None
         self._task = self._loop.create_future()
         return (yield from self._task)
 
-    def close(self):
+    def close(self) -> None:
         """
         Stop and disarm the timer.
         """
+        assert self._loop is not None
         self._loop.remove_reader(self._fd)
         atimer_close(self._fd)
 
@@ -80,7 +85,7 @@ class Timer(object):
         if __debug__:
             logger.debug('timer disarmed')
 
-    def _timer_expired(self):
+    def _timer_expired(self) -> None:
         """
         Handle notification of timer expiration from the timer.
 
@@ -92,6 +97,6 @@ class Timer(object):
         if task and not task.done():
             value = os.read(self._fd, 8)
             value = struct.unpack('Q', value)[0]
-            self._task.set_result(value)
+            self._task.set_result(value)  # type: ignore
 
 # vim: sw=4:et:ai
