@@ -1,7 +1,7 @@
 #
 # atimer - timer library for asyncio
-# 
-# Copyright (C) 2016-2021 by Artur Wroblewski <wrobell@riseup.net>
+#
+# Copyright (C) 2016 - 2024 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ import pytest
 
 NANOSEC = 10 ** 9
 
-def test_to_timespec():
+def test_to_timespec() -> None:
     """
     Test converting float number to `timespec` values, this is second and
     number of nanoseconds.
@@ -35,7 +35,7 @@ def test_to_timespec():
     assert 1 == sec
     assert 10 ** 7 == nsec
 
-def test_timespec_add():
+def test_timespec_add() -> None:
     """
     Test adding time to `timespec` structure.
     """
@@ -46,7 +46,7 @@ def test_timespec_add():
 
 @pytest.mark.asyncio
 @pytest.mark.parametrize('interval', [0.1, 0.25, 0.6, 1, 2])
-async def test_sync_edge_full(interval):
+async def test_sync_edge_full(interval: float) -> None:
     """
     Test synchronizing timer to the edge of interval of realtime clock.
     """
